@@ -1,23 +1,10 @@
-/**
+/*
  * backgroundchecker.cpp
  *
- * Copyright (C)  2004  Zack Rusin <zack@kde.org>
- * Copyright (C)  2009  Jakub Stachowski <qbast@go2.pl>
+ * SPDX-FileCopyrightText: 2004 Zack Rusin <zack@kde.org>
+ * SPDX-FileCopyrightText: 2009 Jakub Stachowski <qbast@go2.pl>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #include "backgroundchecker.h"
 #include "backgroundchecker_p.h"
@@ -61,7 +48,7 @@ void BackgroundCheckerPrivate::checkNext()
         const bool ignoreUpperCase = !currentDict.testAttribute(Speller::CheckUppercase);
         while (mainTokenizer.hasNext()) {
             QStringRef sentence = mainTokenizer.next();
-            if (autodetectLanguage) {
+            if (autodetectLanguage && !autoDetectLanguageDisabled) {
                 if (!mainTokenizer.isSpellcheckable()) {
                     continue;
                 }
@@ -132,8 +119,19 @@ void BackgroundChecker::finishedCurrentFeed()
 {
 }
 
+bool BackgroundChecker::autoDetectLanguageDisabled() const
+{
+    return d->autoDetectLanguageDisabled;
+}
+
+void BackgroundChecker::setAutoDetectLanguageDisabled(bool autoDetectDisabled)
+{
+    d->autoDetectLanguageDisabled = autoDetectDisabled;
+}
+
 void BackgroundChecker::setSpeller(const Speller &speller)
 {
+    d->autoDetectLanguageDisabled = true;
     d->currentDict = speller;
 }
 
@@ -165,6 +163,7 @@ QStringList BackgroundChecker::suggest(const QString &word) const
 void BackgroundChecker::changeLanguage(const QString &lang)
 {
     // this sets language only for current sentence
+    d->autoDetectLanguageDisabled = true;
     d->currentDict.setLanguage(lang);
 }
 
